import { NotificationDataRow, ToastButton } from '@genesislcap/foundation-notifications';
import { NotificationListener } from '@genesislcap/foundation-ui';
import { NotificationsPlatform } from '@openfin/workspace/notifications';
/**
 * @public
 * @remarks
 * OpenfinToastButton interface which extends ToastButton.
 * Adds the task property which is used in mapping button actions to their corresponding callbacks
 */
export interface OpenfinToastButton extends ToastButton {
    task: string;
    cta?: boolean;
    message?: string;
}
/**
 * @public
 * @remarks
 * Openfin Notifications custom element
 */
export declare class OpenfinNotifications extends NotificationListener {
    /**
     * @beta
     * @remarks
     * Config for registering a workspace with the Openfin notifications component
     * @example
     * Create your notifications platform constant
     * ```ts
     * const notificationsPlatform: NotificationsPlatform = {
     *   id: 'platform-id', // the id of your openfin workspace
     *   icon: 'https://localhost:8080/path/to/icon.svg', // the url to the icon for your workspace
     *   title: 'Platform title' // the platform title which will appear in notifications
     * }
     * ```
     * Setting the property in an html view template
     * ```html
     * <openfin-notifications-listener
     *   ...
     *   :notificationsPlatform="${() => notificationsPlatform}"
     * >
     * </openfin-notifications-listener>
     * ```
     */
    notificationsPlatform: NotificationsPlatform;
    /**
     *  @beta
     *  @remarks
     *  The notification type of toast messages
     */
    toast: 'transient' | 'sticky' | 'none';
    /**
     *  @beta
     *  @remarks
     *  The notification sound mode
     */
    mode: 'default' | 'silent';
    /**
     * Array of button configs for openfin notification toasts
     * @public
     * @example
     * In these examples you could
     * 1. View a trade, this is done by routing to the corresponding route. Dispatching the highlighted record id to the store and retrieving it in the view from the store.
     * 2. Call an endpoint to approve a trade
     * 3. Call an endpoint to reject a trade
     * ```html
     * <openfin-notifications-listener
     *   ...
     *   :toastButtons="${x => [
     *     {
     *       {
     *         condition: ({details}) => details.HEADER === 'Trade added',
     *         action: ({details, buttonElement }) => {
     *           Route.path.push('/some-route') // redirect to a route
     *           buttonElement.$emit('some-store-event', details.TABLE_ENTITY_ID); //emit the entity id to the store
     *         }
     *       },
     *       placeholder: 'View Trade',
     *       task: 'view-trade'
     *    },
     *    {
     *       {
     *         condition: ({details}) => details.HEADER === 'Trade added',
     *         action: ({details, buttonElement }) => {
     *           const connect = getConnect();
     *           connect.commitEvent('approve-trade', {
     *             DETAILS: {
     *               TRADE_ID: details.TABLE_ENTITY_ID,
     *               APPROVED: true
     *             }
     *           })
     *         }
     *       },
     *       placeholder: 'Approve Trade',
     *       task: 'approve-trade'
     *    },
     *    {
     *       {
     *         condition: ({details}) => details.HEADER === 'Trade added',
     *         action: ({details, buttonElement }) => {
     *           const connect = getConnect();
     *           connect.commitEvent('approve-trade', {
     *             DETAILS: {
     *               TRADE_ID: details.TABLE_ENTITY_ID,
     *               APPROVED: false
     *             }
     *           })
     *         }
     *       },
     *       placeholder: 'Reject Trade',
     *       task: 'reject-trade'
     *    },
     *
     *  ]
     * >
     * </openfin-notifications-listener>
     * ```
  
     *
     */
    toastButtons: OpenfinToastButton[];
    connectedCallback(): Promise<void>;
    private addButtonListeners;
    protected showNotificationToast(row: NotificationDataRow): Promise<void>;
    private mapToastButtons;
}
//# sourceMappingURL=openfin-notifications-listener.d.ts.map